@@ -5,7 +5,7 @@ use warnings;
 
 use base 'Net::Spotify::Service';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub format_request {
     my ($self, %parameters) = @_;
@@ -36,7 +36,7 @@ Net::Spotify::Lookup - Perl interface to the Spotify Metadata API
 
 =head1 VERSION
 
-Version 0.01
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,7 @@ This module implements the interface to the C<lookup> service of the Spotify
 Metadata API.
 It inherits most of the methods from L<Net::Spotify::Service>.
 
-L<http://developer.spotify.com/en/metadata-api/lookup/>
+L<https://developer.spotify.com/technologies/web-api/lookup/>
 
 =head1 METHODS
 
